#import "TencentMapPlugin.h"
#import <TencentLBS/TencentLBS.h>
#import <CoreLocation/CoreLocation.h>

@interface TencentMapPlugin()<TencentLBSLocationManagerDelegate>

@property(nonatomic, retain) TencentLBSLocationManager *locationManager;

@end

@implementation TencentMapPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel methodChannelWithName:@"tencent_map" binaryMessenger:[registrar messenger]];
  TencentMapPlugin* instance = [[TencentMapPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getLocation" isEqualToString:call.method]) {
      if(!self.locationManager){
          self.locationManager = [[TencentLBSLocationManager alloc] init];
      }
      [self.locationManager setDelegate:self];
      [self.locationManager setPausesLocationUpdatesAutomatically:NO];
      [self.locationManager setRequestLevel:TencentLBSRequestLevelName];
      
      NSString *apiKey = call.arguments[@"apiKey"];
      [self.locationManager setApiKey:apiKey];
      
      CLAuthorizationStatus authorizationStatus = [CLLocationManager authorizationStatus];
      if (authorizationStatus == kCLAuthorizationStatusNotDetermined) {
          [self.locationManager requestWhenInUseAuthorization];
          return;
      }
      [self.locationManager requestLocationWithCompletionBlock:^(TencentLBSLocation *location, NSError *error) {
          if(error){
              result(@{@"code":@(-1),@"error":error});
          }else{
              CLLocation *clLocation = location.location;
              CLLocationCoordinate2D coordinate=clLocation.coordinate;
              NSDictionary *data = @{
                  @"name":location.name,
                  @"address":location.address,
                  @"city":location.city,
                  @"cityCode":location.code,
                  @"latitude":@(coordinate.latitude),
                  @"longitude":@(coordinate.longitude)
              };
            result(data);
          }
      }];
  }else if ([@"isOpenGPS" isEqualToString:call.method]) {
      if ([CLLocationManager locationServicesEnabled] == YES){
          result(@YES);
      }else{
          result(@NO);
      }
  } else if ([@"enableGPS" isEqualToString:call.method]) {
      NSURL *url = [NSURL URLWithString:UIApplicationOpenSettingsURLString];
      if ([[UIApplication sharedApplication] canOpenURL:url]) {
          [[UIApplication sharedApplication] openURL:url];
      }
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end
